==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/WorkflowStateActionAclFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link WorkflowStateActionAcl}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class WorkflowStateActionAclFieldAttributes extends AbstractBeanAttributesDefinition{

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_STATE_ACTION_ACL")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** workflowStateAction (Database column: STATE_ACTION_ID) */
    static public AttributeDefinition workflowStateAction =
        new AttributeDefinition("workflowStateAction")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_STATE_ACTION_ACL")
                .setDatabaseId("STATE_ACTION_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowStateAction.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowStateAction.class);

    /** userId (Database column: USER_ID) */
    static public AttributeDefinition userId =
        new AttributeDefinition("userId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_STATE_ACTION_ACL")
                .setDatabaseId("USER_ID")
                .setMandatory(true)
                .setMaxSize(1000)
                .setType(String.class);

    /** workflowUserProfile (Database column: USER_PROFILE_ID) */
    static public AttributeDefinition workflowUserProfile =
        new AttributeDefinition("workflowUserProfile")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_STATE_ACTION_ACL")
                .setDatabaseId("USER_PROFILE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(id.getName(),id);
        map.put(workflowStateAction.getName(),workflowStateAction);
        map.put(userId.getName(),userId);
        map.put(workflowUserProfile.getName(),workflowUserProfile);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/WorkflowStateActionAclFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link WorkflowStateActionAcl}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class WorkflowStateActionAclFieldAttributes extends AbstractBeanAttributesDefinition{

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_STATE_ACTION_ACL")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setType(Long.class);

    /** workflowStateAction (Database column: STATE_ACTION_ID) */
    static public AttributeDefinition workflowStateAction =
        new AttributeDefinition("workflowStateAction")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_STATE_ACTION_ACL")
                .setDatabaseId("STATE_ACTION_ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowStateAction.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowStateAction.class);

    /** userId (Database column: USER_ID) */
    static public AttributeDefinition userId =
        new AttributeDefinition("userId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_STATE_ACTION_ACL")
                .setDatabaseId("USER_ID")
                .setMandatory(false)
                .setMaxSize(1000)
                .setType(String.class);

    /** workflowUserProfile (Database column: USER_PROFILE_ID) */
    static public AttributeDefinition workflowUserProfile =
        new AttributeDefinition("workflowUserProfile")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_STATE_ACTION_ACL")
                .setDatabaseId("USER_PROFILE_ID")
                .setMandatory(false)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.WorkflowUserProfile.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(id.getName(),id);
        map.put(workflowStateAction.getName(),workflowStateAction);
        map.put(userId.getName(),userId);
        map.put(workflowUserProfile.getName(),workflowUserProfile);

        return map;
    }
}
